.. _core_user_logged_in:

======================
Manage Logged In Users
======================

Overview
````````

This screen shows the logged in users in Peek. Administrators can logout users
from this screen.

:User Name: The users username.
:User Title: The full name of the user.
:Login Date: The timestamp of when the user previously logged in.
:Vehicle: The vehicle registration if entered into Peek Field.
:Device Type: The type of device that is logged in. Eg. office-web for browser.
:Device Title: The unique identifier for the device logged in.
:Last Online: The timestamp of the last time the user was online.

.. image:: manage-logged-in-users.png

Logout a User
`````````````
Click on the **Logout User** button for a user.

.. image:: logout_user.png

----

Click on **Yes**

.. image:: logout_yes.png